"""Stochastic study of the ANUGA implementation of the
shallow water wave equation.

This script runs the model for one realisation of bathymetry as
given in the file bathymetry.txt and outputs a full simulation is \
sww NetCDF format.

The left boundary condition is a timeseries defined in
NetCDF file: input_wave.tms

Note: This scripts needs create_mesh.py to have been run

Suresh Kumar and Ole Nielsen 2006
"""


#------------------------------------------------------------------------------
# Import necessary modules
#------------------------------------------------------------------------------

# Standard modules
import os
import time

# Related major packages
from pyvolution.shallow_water import Domain
from pyvolution.shallow_water import Reflective_boundary
from pyvolution.shallow_water import Transmissive_Momentum_Set_Stage_boundary
from pyvolution.pmesh2domain import pmesh_to_domain_instance
from pyvolution.data_manager import xya2pts
from pyvolution.util import file_function

# Application specific imports
import project                 # Definition of file names and polygons


#-----------------------------------------------------------------------------
# Setup computational domain
#----------------------------------------------------------------------------- 
print 'Creating domain from', project.mesh_filename

domain = pmesh_to_domain_instance(project.mesh_filename, Domain,
                                  use_cache=True,
                                  verbose=True)

print 'Number of triangles = ', len(domain)
print 'The extent is ', domain.get_extent()

domain.set_name(project.basename)
domain.set_datadir('.')
domain.set_quantities_to_be_stored(['stage', 'xmomentum', 'ymomentum'])

domain.check_integrity()


#------------------------------------------------------------------------------
# Setup initial conditions
#------------------------------------------------------------------------------
domain.set_quantity('elevation',
                    filename = project.bathymetry_filename[:-4] + '.pts',
                    alpha = 0.001,
                    verbose = True,
                    use_cache = True)

domain.set_quantity('friction', 0.0)
domain.set_quantity('stage', 0.0)


#------------------------------------------------------------------------------
# Setup boundary conditions
#------------------------------------------------------------------------------

function = file_function(project.boundary_filename, domain, verbose = True)
Bts = Transmissive_Momentum_Set_Stage_boundary(domain, function) #Input wave
Br = Reflective_boundary(domain) #Wall

# Bind boundary objects to tags
domain.set_boundary({'wave': Bts, 'wall': Br})


#------------------------------------------------------------------------------
# Evolve system through time
#------------------------------------------------------------------------------
t0 = time.time()
for t in domain.evolve(yieldstep = 0.05, finaltime = 22.5):
    domain.write_time()
    domain.write_boundary_statistics(tags = 'wave')         

print 'That took %.2f seconds' %(time.time()-t0)
